Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/editors/mesh/bmesh_utils.c')
-rw-r--r--source/blender/editors/mesh/bmesh_utils.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/source/blender/editors/mesh/bmesh_utils.c b/source/blender/editors/mesh/bmesh_utils.c
index 892184e94ad..0f9bc29a16d 100644
--- a/source/blender/editors/mesh/bmesh_utils.c
+++ b/source/blender/editors/mesh/bmesh_utils.c
@@ -73,7 +73,7 @@ void EDBM_ClearMesh(BMEditMesh *em)
em->derivedCage = em->derivedFinal = NULL;
/* free tesselation data */
em->tottri = 0;
if (em->looptris)
MEM_freeN(em->looptris);
@@ -143,7 +143,7 @@ int EDBM_FinishOp(BMEditMesh *em, BMOperator *bmop, wmOperator *op, const int re
BMEdit_Free(em);
*em = *emcopy;
- BMEdit_RecalcTesselation(em);
+ BMEdit_RecalcTessellation(em);
MEM_freeN(emcopy);
em->emcopyusers = 0;
@@ -521,13 +521,13 @@ static void *editbtMesh_to_undoMesh(void *emv, void *obdata)
#ifdef BMESH_EM_UNDO_RECALC_TESSFACE_WORKAROUND
- /* we recalc the tesselation here, to avoid seeding calls to
- * BMEdit_RecalcTesselation throughout the code. */
- BMEdit_RecalcTesselation(em);
+ /* we recalc the tessellation here, to avoid seeding calls to
+ * BMEdit_RecalcTessellation throughout the code. */
+ BMEdit_RecalcTessellation(em);
#endif
- BMO_op_callf(em->bm, "bmesh_to_mesh mesh=%p notesselation=%b", &um->me, TRUE);
+ BMO_op_callf(em->bm, "bmesh_to_mesh mesh=%p notessellation=%b", &um->me, TRUE);
um->selectmode = em->selectmode;
return um;
@@ -73,7 +73,7 @@ void EDBM_ClearMesh(BMEditMesh *em)
em->derivedCage = em->derivedFinal = NULL;
- /* free tesselation data */
+ /* free tessellation data */
em->tottri = 0;
if (em->looptris)